@@ -5,6 +5,7 @@ from unittest.mock import Mock
 
 import numpy as np
 import pytest
+from pydantic import PrivateAttr
 from typing_extensions import Protocol, runtime_checkable
 
 from psygnal import EventedModel, SignalGroup
@@ -489,3 +490,52 @@ def test_unrecognized_property_dependencies():
                 property_dependencies = {"y": ["b"]}
 
     assert "Unrecognized field dependency: 'b'" in str(e[0])
+
+
+def test_setattr_before_init():
+    class M(EventedModel):
+        _x: int = PrivateAttr()
+
+        def __init__(_model_self_, x: int, **data) -> None:
+            _model_self_._x = x
+            super().__init__(**data)
+
+        @property
+        def x(self) -> int:
+            return self._x
+
+    m = M(x=2)
+    assert m.x == 2
+
+
+def test_setter_inheritance():
+    class M(EventedModel):
+        _x: int = PrivateAttr()
+
+        def __init__(self, x: int, **data) -> None:
+            self.x = x
+            super().__init__(**data)
+
+        @property
+        def x(self) -> int:
+            return self._x
+
+        @x.setter
+        def x(self, v: int) -> None:
+            self._x = v
+
+        class Config:
+            allow_property_setters = True
+
+    assert M(x=2).x == 2
+
+    class N(M):
+        ...
+
+    assert N(x=2).x == 2
+
+    with pytest.raises(ValueError, match="Cannot set 'allow_property_setters' to"):
+
+        class Bad(M):
+            class Config:
+                allow_property_setters = False
